@@ -17,7 +17,7 @@ package PostScript::Report;
 # ABSTRACT: Produce formatted reports in PostScript
 #---------------------------------------------------------------------
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use 5.008;
 use Moose;
@@ -818,9 +818,9 @@ PostScript::Report - Produce formatted reports in PostScript
 
 =head1 VERSION
 
-This document describes version 0.05 of
-PostScript::Report, released February 26, 2010
-as part of PostScript-Report version 0.05.
+This document describes version 0.06 of
+PostScript::Report, released March 26, 2010
+as part of PostScript-Report version 0.06.
 
 =head1 SYNOPSIS
 
@@ -1210,10 +1210,10 @@ Unicode in PostScript is non-trivial.
 
 =head1 AUTHOR
 
-Christopher J. Madsen  S<< C<< <perl AT cjmweb.net> >> >>
+Christopher J. Madsen  C<< <perlATcjmweb.net> >>
 
 Please report any bugs or feature requests to
-S<< C<< <bug-PostScript-Report AT rt.cpan.org> >> >>,
+C<< <bug-PostScript-ReportATrt.cpan.org> >>,
 or through the web interface at
 L<http://rt.cpan.org/Public/Bug/Report.html?Queue=PostScript-Report>
 
